@@ -1112,7 +1112,7 @@ _RE_ACLOBJECT = re.compile(_RE_ACLOBJECT_STR, re.VERBOSE)
 
 class ASAAclLine(ASACfgLine):
     def __init__(self, *args, **kwargs):
-        """Provide attributes on Cisco ASA Access-Lists""" # FIXME
+        """Provide attributes on Cisco ASA Access-Lists"""
         super(ASAAclLine, self).__init__(*args, **kwargs)
         mm = _RE_ACLOBJECT.search(self.text)
         if not (mm is None):
